%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Technical Note TN138
% Parameters for 'V/f control of an induction machine'
% Copyright imperix ltd, 2021
% dev@imperix.ch
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% =================== System parameters ======================== %%

ControlFreq    = 20e3;              % Control interrupt frequency [Hz]
ControlPeriod  = 1/ControlFreq;     % Control interrupt period [s]
SamplingPeriod = ControlPeriod;     % Sampling period [s]

% Deadtime
dt = 1e-6;


%% =================== Plant model ======================== %%

% Induction machine (IM)
% Leroy-Somer 2P LSES 100L 3kW
IM.p = 1;               % Nb of pole pair [-]
IM.Usn = 230;           % Rated phase voltage [V]
IM.Isn = 6.1;           % Rated current [A]
IM.fsn = 50;            % Rated stator frequency [Hz]
IM.wsn = 2*pi*IM.fsn;   % Rated angular frequency [rad/s]
IM.Wrn = 2870;          % Nominal rotor speed [rpm]
IM.Rs = 1.5;            % Stator resistance [Ohm]
IM.Rr = 1.4;            % Rotor resistance [Ohm]
IM.Jm = 0.00364;        % Moment of inertia [kg m^2]
IM.Temn = 9.9;          % Nominal torque [Nm]

IM.cos_phi = 0.88;      % Power factor [-]
IM.sin_phi = sqrt(1 - IM.cos_phi^2);

IM.Lsigma = 0.0288;                 % Total leakage inductance [H]
IM.Lm = 0.2951;                     % Mutual inductance [H]
IM.Lgs = 0.012;                     % Stator leakage inductance [H]
IM.Ls = IM.Lgs + IM.Lm;             % Stator inductance [H]
IM.Lr = IM.Lm^2/(IM.Ls-IM.Lsigma);  % Rotor inductance [H]
IM.Lgr = IM.Lr - IM.Lm;             % Rotor leakage inductance [H]

Is_re = IM.Isn*IM.cos_phi;
Is_im = IM.Isn*IM.sin_phi;
Um_re = IM.Usn - IM.Rs*Is_re + IM.wsn*IM.Lgs*Is_im;     % Voltage across Lm (real)
Um_im = -IM.Rs*Is_im - IM.wsn*IM.Lgs*Is_re;             % Voltage across Lm (imaginary)
Um = sqrt(Um_re^2 + Um_im^2);                           % Voltage across Lm (norm)

IM.Idsn = (sqrt(2)*Um) / (IM.wsn*IM.Lm);       % Nominal d-axis current
IM.Psi_d_n = IM.Lm * IM.Idsn;                  % Nominal rotor flux

% Encoder parameters
PPR     = 4096;         % Encoder pulses per turn [-]

%% ============== DC link - Voltage control =============== %%

% Breaking chopper (optional)
DcLink.Rbr  = 50;		% Braking chopper resistor [Ohm]
DcLink.Vdc0 = 750;      % Initial DC bus voltage [V]


%% ========================== V/f control ============================= %%

Vf.Vmin = 0.1 * IM.Usn;                 % Minimal voltage [V]
Vf.f_min = IM.fsn * Vf.Vmin/IM.Usn;     % Minimal frequency [Hz]

